pilas.motores.motor_qt.Imagen

Package pilas :: Package motores :: Module motor_qt :: Class Imagen |
[hide private]
[frames] | no frames]

# Class Imagen

source code

    object --+
             |
            Imagen

Instance Methods | [hide private]
__init__(self, ruta) x.__init__(...) initializes x; see help(type(x)) for signature | source code
cargar_jpeg(self, ruta) | source code
ancho(self) | source code
alto(self) | source code
centro(self) Retorna una tupla con la coordenada del punto medio del la imagen. | source code
avanzar(self) | source code
dibujar(self, painter, x, y, dx=0, dy=0, escala_x=1, escala_y=1, rotacion=0, transparencia=0) Dibuja la imagen sobre la ventana que muestra el motor. | source code
_dibujar_pixmap(self, painter, x, y) | source code
__str__(self) str(x) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ruta) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### dibujar(self, painter, x, y, dx=0, dy=0, escala_x=1, escala_y=1, rotacion=0, transparencia=0) | source code
Dibuja la imagen sobre la ventana que muestra el motor. x, y: indican la posicion dentro del mundo. dx, dy: es el punto centro de la imagen (importante para rotaciones). escala_x, escala_yindican cambio de tamano (1 significa normal). rotacion: angulo de inclinacion en sentido de las agujas del reloj.

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)